@@ -1,11 +1,11 @@
 package Tapper::MCP::Child;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Control one specific testrun on MCP side
-$Tapper::MCP::Child::VERSION = '5.0.0';
+$Tapper::MCP::Child::VERSION = '5.0.1';
 use 5.010;
 use strict;
 use warnings;
-no warnings "experimental::smartmatch";
+no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
 use Class::Load 'load_class';
 use Hash::Merge::Simple qw/merge/;
@@ -152,7 +152,7 @@ sub handle_error
 
 sub start_testrun
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self, $config) = @_;
 
         my $net    = Tapper::MCP::Net->new();
