@@ -1,9 +1,9 @@
 package Tapper::MCP::Config;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::Config::VERSION = '5.0.0';
+$Tapper::MCP::Config::VERSION = '5.0.1';
 use strict;
 use warnings;
-no warnings "experimental::smartmatch";
+no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
 use 5.010;
 use Data::DPath 'dpath';
@@ -111,7 +111,7 @@ sub handle_guest_tests
 
 sub parse_virt_host
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self, $config, $virt) = @_;
         given (lc($virt->{host}->{root}->{precondition_type})) {
                 when ('image') {
@@ -160,7 +160,7 @@ sub parse_virt_preconditions
 
                 # if we have a qcow image, we need a raw image to copy PRC stuff to
                 no warnings 'uninitialized';
-                no warnings "experimental::smartmatch";
+                no if $] >= 5.017011, warnings => 'experimental::smartmatch';
                 given($guest->{root}{mounttype})
                 {
                         when ('raw') {
@@ -450,7 +450,7 @@ sub produce_preconds_in_arrayref
 
 sub produce_virt_precondition
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self, $config, $precondition) = @_;
         local $Data::DPath::USE_SAFE; # path not from user, Safe.pm deactivated for debug and speed
         my $producers = $precondition ~~ dpath '//*[key eq "precondition_type" and lc(value) eq "produce"]/../..';
@@ -480,7 +480,7 @@ sub produce_virt_precondition
 
 sub parse_precondition
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self, $config, $precondition_result) = @_;
         my $precondition = $precondition_result->precondition_as_hash;
 
