@@ -1,6 +1,6 @@
 package Tapper::MCP::Scheduler::Job;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::Scheduler::Job::VERSION = '5.0.0';
+$Tapper::MCP::Scheduler::Job::VERSION = '5.0.1';
 use strict;
 use warnings;
 
@@ -91,7 +91,7 @@ sub match_host {
 
 our @functions;
 BEGIN {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my $features = Tapper::Model::model->resultset('HostFeature')->search(
                                                                               {
                                                                               },
