@@ -1,10 +1,10 @@
 package Tapper::MCP::State;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::State::VERSION = '5.0.0';
+$Tapper::MCP::State::VERSION = '5.0.1';
 use 5.010;
 use strict;
 use warnings;
-no warnings "experimental::smartmatch";
+no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
 use Moose;
 use List::Util qw/max min reduce/;
@@ -142,7 +142,7 @@ sub compare_given_state
 
 sub get_current_timeout_span
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self) = @_;
         my $new_timeout_date;
         my $keep_alive_timeout_date = $self->state_details->keep_alive_timeout_date;
@@ -176,7 +176,7 @@ sub state_init
 
 sub update_installer_timeout
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self) = @_;
         my $now = time();
         my $installer_timeout_date = $self->state_details->installer_timeout_current_date;
@@ -197,7 +197,7 @@ sub update_installer_timeout
 
 sub update_prc_timeout
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self, $prc_number) = @_;
         my $now = time();
         if ($self->state_details->prc_timeout_current_date($prc_number) < $now) {
@@ -229,7 +229,7 @@ sub update_prc_timeout
 
 sub update_test_timeout
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self) = @_;
         my $now = time();
 
@@ -303,7 +303,7 @@ sub update_keep_alive_timeout
 
 
 sub update_timeouts {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self) = @_;
         my ( $error, $timeout_span );
 
@@ -567,7 +567,7 @@ sub msg_keep_alive
 
 sub next_state
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self, $msg) = @_;
         my ($error, $timeout_span);
 
