@@ -1,10 +1,10 @@
 package Tapper::MCP::State::Details;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::State::Details::VERSION = '5.0.0';
+$Tapper::MCP::State::Details::VERSION = '5.0.1';
 use 5.010;
 use strict;
 use warnings;
-no warnings "experimental::smartmatch";
+no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
 use Moose;
 use List::Util qw/max min/;
@@ -234,7 +234,7 @@ sub is_all_prcs_finished
 
 sub prc_next_timeout
 {
-        no warnings "experimental::smartmatch";
+        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my ($self, $num) = @_;
         my $prc = $self->state_details->{prcs}->[$num];
         my $default_timeout = 60 + 60; # (time between SIGTERM and SIGKILL in PRC) + (grace period for sending the message)
